@@ -47,12 +47,12 @@ MooseX::App::Role - Use documentation attributes in a role
  
  has 'testattr' => (
     isa             => 'rw',
-    command_tags    => [qw(Important! Nice))],
+    cmd_tags        => [qw(Important! Nice))],
  );
 
 =head1 DESCRIPTION
 
-When loading this package in a role you can use the C<command_tags>
+When loading this package in a role you can use the C<cmd_tags>
 attribute to document an attribute. 
 
 Alternatively you can also just use attribute traits:
@@ -60,7 +60,9 @@ Alternatively you can also just use attribute traits:
  has 'testattr' => (
     isa             => 'rw',
     traits          => [qw(App::Tags)]
-    command_tags    => [qw(Important! Nice))],
+    cmd_tags        => [qw(Important! Nice))],
  );
 
+All attibutes available in L<MooseX::Getopt::Meta::Attribute::Trait> are also applied
+
 =cut
\ No newline at end of file
